@@ -10,6 +10,7 @@ __email__ = 'matt@nycresistor.com'
 __copyright__ = 'Copyright 2016, Symphony Communication Services LLC'
 
 import hashlib
+import tempfile
 from OpenSSL import crypto
 
 
@@ -20,8 +21,8 @@ class Crypt():
         self.pwd = symphony_pwd
 
     def write_tmpfile(self, string):
-        path = '/tmp/' + hashlib.sha224(string).hexdigest()
-        filehandle = open(path, 'w')
+        fd, path = tempfile.mkstemp()
+        filehandle = open(path, 'wb')
         filehandle.write(string)
         filehandle.close
         return path
